<?php
namespace ImageCode\WiredmindsLeadlab;
	
use TYPO3\CMS\Backend\Utility\BackendUtility;
use TYPO3\CMS\Core\Messaging\FlashMessage;
use TYPO3\CMS\Core\Utility\GeneralUtility;


class ext_update
{

	/**
	 * @var \TYPO3\CMS\Core\Messaging\FlashMessageQueue
	 * @inject
	 */
	protected $flashMessageQueue;

	/**
	 * @var string
	 */
	protected $extensionKey = 'wiredminds_leadlab';

	/**
	 * Check if upgrade script is needed (this function is called from the extension manager)
	 *
	 * @return boolean
	 */
	public function access()
	{
		return $this->getBackendUserAuthentication()->isAdmin();
	}

	/**
	 * Run upgrade scripts (this function is called from the extension manager)
	 *
	 * @return string
	 */
	public function main()
	{
		$updateScriptLink = BackendUtility::getModuleUrl('tools_ExtensionmanagerExtensionmanager', [
				'tx_extensionmanager_tools_extensionmanagerextensionmanager' => [
					'extensionKey' => $this->extensionKey,
					'action' => 'show',
					'controller' => 'UpdateScript',
				],
		]);
		$view = $this->getView();
		$viewValues = ['formAction' => $updateScriptLink];

		if ((int) GeneralUtility::_GP('doSomething') === 1) {
			$contentElements = $this->doSomething();
			$viewValues['contentElements'] = $contentElements;
		}

		$view->assignMultiple($viewValues);

		return $view->render();
	}

	/**
	 * Get tt_content data
	 *
	 * @return array
	 */
	protected function doSomething()
	{
		$SELECT='uid, title, tx_leadlab_ll_disable, tx_leadlab_ll_milestone, tx_leadlab_ll_page_name, tx_leadlab_ll_group_name';
		$FROM = 'pages';
		$WHERE = 'deleted=0 AND ((tx_leadlab_ll_milestone IS NOT NULL AND tx_leadlab_ll_milestone != "") OR (tx_leadlab_ll_page_name IS NOT NULL AND tx_leadlab_ll_page_name != "") OR (tx_leadlab_ll_group_name IS NOT NULL AND tx_leadlab_ll_group_name != "")) ';


		$res = $GLOBALS["TYPO3_DB"]->exec_SELECTquery($SELECT,$FROM,$WHERE);
		$anzahl=count($this->getDatabaseConnection()->exec_SELECTgetRows($SELECT,$FROM,$WHERE));

		while ($row = $GLOBALS["TYPO3_DB"]->sql_fetch_assoc($res)) {
			$execFIELDS['ll_disable']=$row['tx_leadlab_ll_disable'];
			$execFIELDS['ll_milestone']=$row['tx_leadlab_ll_milestone'];
			$execFIELDS['ll_page_name']=$row['tx_leadlab_ll_page_name'];
			$execFIELDS['ll_group_name']=$row['tx_leadlab_ll_group_name'];

			$success = $GLOBALS['TYPO3_DB']->exec_UPDATEquery("pages", 'uid='.$row['uid'], $execFIELDS);
			if ($success) {
				$fbsql = true;	
			} else {
				$fbsql = false;	
			}
		}
		

		/* @var $message \TYPO3\CMS\Core\Messaging\FlashMessage */
		if ($anzahl > 0) {
			$message = $this->getObjectManager()->get(
				\TYPO3\CMS\Core\Messaging\FlashMessage::class, 'Migrated the following page-settings (a total of ' . $anzahl . ' pages). You can delete the old leadlab-Extension now.', 'Content elements found', FlashMessage::OK
			);
		} else {
			$message = $this->getObjectManager()->get(
				\TYPO3\CMS\Core\Messaging\FlashMessage::class, 'No content elements found... maybe, there was no former leadlab-installation?', 'Nothing to do', FlashMessage::ERROR
			);
		}
		$this->getFlashMessageQueue()->enqueue($message);
		return $res;
	}

	/**
	 * @return \TYPO3\CMS\Extbase\Object\ObjectManager
	 */
	protected function getObjectManager()
	{
		return GeneralUtility::makeInstance(\TYPO3\CMS\Extbase\Object\ObjectManager::class);
	}

	/**
	 * @return \TYPO3\CMS\Core\Database\DatabaseConnection
	 */
	protected function getDatabaseConnection()
	{
		return $GLOBALS['TYPO3_DB'];
	}

	/**
	 * @return \TYPO3\CMS\Core\Authentication\BackendUserAuthentication
	 */
	protected function getBackendUserAuthentication()
	{
		return $GLOBALS['BE_USER'];
	}

	/**
	 * @return \TYPO3\CMS\Fluid\View\StandaloneView
	 */
	protected function getView()
	{
		/* @var $view \TYPO3\CMS\Fluid\View\StandaloneView */
		$view = $this->getObjectManager()->get(\TYPO3\CMS\Fluid\View\StandaloneView::class);
		$view->setTemplatePathAndFilename(GeneralUtility::getFileAbsFileName('EXT:' . $this->extensionKey . '/Resources/Private/Templates/UpdateScript/Index.html'));
		$view->setLayoutRootPaths([GeneralUtility::getFileAbsFileName('EXT:' . $this->extensionKey . '/Resources/Private/Layouts')]);
		$view->setPartialRootPaths([GeneralUtility::getFileAbsFileName('EXT:' . $this->extensionKey . '/Resources/Private/Partials')]);
		return $view;
	}

	/**
	 * @return \TYPO3\CMS\Core\Messaging\FlashMessageQueue
	 */
	protected function getFlashMessageQueue()
	{
		if (!isset($this->flashMessageQueue)) {
			/* @var $flashMessageService \TYPO3\CMS\Core\Messaging\FlashMessageService */
			$flashMessageService = $this->getObjectManager()->get(\TYPO3\CMS\Core\Messaging\FlashMessageService::class);
			$this->flashMessageQueue = $flashMessageService->getMessageQueueByIdentifier('reintcontentelements.errors');
		}
		return $this->flashMessageQueue;
	}
}
